@@ -1,5 +1,5 @@
 """JQuery-Ajax Autocomplete fields for Django Forms"""
-__version__ = "1.2"
+__version__ = "1.2.4"
 __author__ = "crucialfelix"
 __contact__ = "crucialfelix@gmail.com"
 __homepage__ = "http://code.google.com/p/django-ajax-selects/"
@@ -69,7 +69,7 @@ class LookupChannel(object):
 
 
 
-def make_ajax_form(model,fieldlist,superclass=ModelForm,show_m2m_help=False):
+def make_ajax_form(model,fieldlist,superclass=ModelForm,show_help_text=False,**kwargs):
     """ Creates a ModelForm subclass with autocomplete fields
             
         usage:
@@ -82,7 +82,10 @@ def make_ajax_form(model,fieldlist,superclass=ModelForm,show_m2m_help=False):
         and
             'author' is a ForeignKeyField specifying here to also use the lookup channel 'contact'
     """
-
+    # will support previous arg name for several versions before deprecating
+    if 'show_m2m_help' in kwargs:
+        show_help_text = kwargs.pop('show_m2m_help')
+        
     class TheForm(superclass):
         
         class Meta:
@@ -90,7 +93,7 @@ def make_ajax_form(model,fieldlist,superclass=ModelForm,show_m2m_help=False):
         setattr(Meta, 'model', model)
 
     for model_fieldname,channel in fieldlist.iteritems():
-        f = make_ajax_field(model,model_fieldname,channel,show_m2m_help)
+        f = make_ajax_field(model,model_fieldname,channel,show_help_text)
 
         TheForm.declared_fields[model_fieldname] = f
         TheForm.base_fields[model_fieldname] = f
@@ -99,24 +102,22 @@ def make_ajax_form(model,fieldlist,superclass=ModelForm,show_m2m_help=False):
     return TheForm
 
 
-def make_ajax_field(model,model_fieldname,channel,show_m2m_help = False,**kwargs):
+def make_ajax_field(model,model_fieldname,channel,show_help_text = False,**kwargs):
     """ Makes a single autocomplete field for use in a Form
 
         optional args:
-            help_text - default is the model field's help_text 
-            label     - default is the model field's verbose name
-            required  - default is the model field's (not) blank
+            help_text - default is the model db field's help_text. 
+                None will disable all help text
+            label     - default is the model db field's verbose name
+            required  - default is the model db field's (not) blank
         
-            show_m2m_help - 
-                Django will show help text in the Admin for ManyToMany fields,
-                in which case the help text should not be shown in side the widget itself
-                or it appears twice.
-                
-                ForeignKey fields do not behave like this.
-                ManyToMany inside of admin inlines do not do this. [so set show_m2m_help=True]
-    
-                But if used outside of the Admin or in an ManyToMany admin inline then you need the help text.
+            show_help_text - 
+                Django will show help text below the widget, but not for ManyToMany inside of admin inlines
+                This setting will show the help text inside the widget itself.
     """
+    # will support previous arg name for several versions before deprecating
+    if 'show_m2m_help' in kwargs:
+        show_help_text = kwargs.pop('show_m2m_help')
 
     from ajax_select.fields import AutoCompleteField, \
                                    AutoCompleteSelectMultipleField, \
@@ -140,8 +141,8 @@ def make_ajax_field(model,model_fieldname,channel,show_m2m_help = False,**kwargs
     else:
         required = not field.blank
 
+    kwargs['show_help_text'] = show_help_text
     if isinstance(field,ManyToManyField):
-        kwargs['show_help_text'] = show_m2m_help
         f = AutoCompleteSelectMultipleField(
             channel,
             required=required,
