@@ -15,14 +15,11 @@ class ReleaseForm(ModelForm):
     group  = make_ajax_field(Release,'group','group')
     
     # no help text at all
-    label  = make_ajax_field(Release,'label','label',help_text=None)
+    label  = make_ajax_field(Release,'label','label',help_text="Search for label by name")
     
     # any extra kwargs are passed onto the field, so you may pass a custom help_text here
     songs = make_ajax_field(Release,'songs','song',help_text=u"Search for song by title")
 
-    # if you are creating a form for use outside of the django admin to specify show_m2m_help=True :
-    # label  = make_ajax_field(Release,'label','label',show_m2m_help=True)
-    # so that it will show the help text in manytomany fields 
-
-    title = make_ajax_field(Release,'title','cliche',help_text=u"Autocomplete will search the database for clichés about cats.")
+    # these are from a fixed array defined in lookups.py
+    title = make_ajax_field(Release,'title','cliche',help_text=u"Autocomplete will suggest clichés about cats.")
 
